from .ai_models.ai_search import *
from .ai_models.content_mod import *
from .ai_models.image_analysis import *
from .ai_models.image_gen import *
from .ai_models.model_train import *
from .ai_models.text_extract import *
from .ai_models.text_gen import *
from .database_management.collection import *
from .database_management.Edit import *
from .database_management.Read import *


import requests
import os


def extract_pdf_text(pdf_file=None, api_key=None):
    if not pdf_file:
        return "PDF file is missing"
    if not api_key:
        api_key = os.getenv("API_KEY")
        print(api_key)
    if not api_key:
        raise ValueError("API key is missing. Provide it as an argument or in the .env file.")
    url = "https://api.worqhat.com/api/ai/v2/pdf-extract"
    headers = {
        "Authorization": f"Bearer {api_key}"
    }
    files = [('file', (os.path.basename(pdf_file), open(pdf_file, 'rb'), 'application/pdf'))]
    response = requests.post(url, files=files, headers=headers)
    return response.text

def web_extract(url_search="", headline=True, inline_code=True, code_blocks=True, references=True, tables=True, api_key=None):
    if url_search=="":
        raise ValueError("No URL provided")
    if not api_key:
        api_key = os.getenv("API_KEY")
    if not api_key:
        raise ValueError("API key is missing. Provide it as an argument or in the .env file.")
    url = "https://api.worqhat.com/api/ai/v2/web-extract"
    headers = {
        "Authorization": "Bearer " + api_key,
        "Content-Type": "application/json"
    }
    payload = {
        "url_path": url_search,
        "headline": headline,
        "inline_code": inline_code,
        "code_blocks": code_blocks,
        "references": references,
        "tables": tables
    }
    response = requests.post(url, json=payload, headers=headers)
    return response.text


def detect_image_text(image=None, output_type="text", api_key=None):

    if not image or len(image) == 0:
        raise ValueError("Images are missing")
    if not api_key:
        api_key = os.getenv("API_KEY")
    if not api_key:
        raise ValueError("API key is missing. Provide it as an argument or in the .env file.")
    url = "https://api.worqhat.com/api/ai/images/v2/image-text-detection"
    headers = {
        "Authorization": f"Bearer {api_key}"
    }
    results = []
    payload = {'output_type': output_type}
    if image.startswith('http://') or image.startswith('https://'):
        response = requests.get(image)
        files = [('image', (os.path.basename(image), response.content, 'image/jpeg'))]
    else:
        with open(image, 'rb') as f:
            files = [('image', (os.path.basename(image), f, 'image/jpeg'))]
        response = requests.post(url, headers=headers, data=payload, files=files)
        results.append(response.text)
    return results


def convert_speech_to_text(audio_file=None, api_key=None):
    if not audio_file:
        raise ValueError("Audio file is missing")
    if not api_key:
        api_key = os.getenv("API_KEY")
    if not api_key:
        raise ValueError("API key is missing. Provide it as an argument or in the .env file.")
    url = "https://api.worqhat.com/api/ai/speech-text"
    headers = {
        "Authorization": f"Bearer {api_key}"
    }
    files = [('audio', (os.path.basename(audio_file), open(audio_file, 'rb'), 'application/octet-stream'))]
    response = requests.post(url, files=files, headers=headers)
    return response.text


import requests 
import os


def content_moderation(text_content="",api_key=None):
    if text_content == "":
        return "Text content is incomplete. Please give some text and try again. "
    if not api_key:
        api_key = os.getenv("API_KEY")
    if not api_key:
        raise ValueError("API key is missing. Provide it as an argument or in the .env file.")
    url = "https://api.worqhat.com/api/ai/moderation"
    headers = {
        "Authorization": "Bearer " + api_key,
        "Content-Type": "application/json"
    }
    payload = {
        "text_content": text_content
    }
    response = requests.post(url, json=payload, headers=headers)
    return response.text

def image_moderation(image=None, api_key=None):
    if not image or len(image) == 0:
        return "No images found. Please try again "
    if not api_key:
        api_key = os.getenv("API_KEY")
    if not api_key:
        raise ValueError("API key is missing. Provide it as an argument or in the .env file.")
    url = "https://api.worqhat.com/api/ai/images/v2/image-moderation"
    headers = {
        "Authorization": f"Bearer {api_key}"
    }
       
    if image.startswith('http://') or image.startswith('https://'):        
        response = requests.get(image)
        files = [('image', ('file', response.content, 'application/octet-stream'))]
    else:
        with open(image, 'rb') as f:
            files = [('image', ('file', f, 'application/octet-stream'))]
    response = requests.post(url, files=files, headers=headers)
    return response.text

    


import unittest
from unittest.mock import MagicMock
import requests
from ..src.ai_models.text_gen import (get_ai_responsev2, get_ai_responsev3, 
                         get_large_ai_response_v2, get_alpha_ai_response)

class TestAIResponses(unittest.TestCase):

    def setUp(self):
        # Mock API key for testing
        self.api_key = "mock_api_key"

    def test_get_ai_responsev2(self):
        # Mock response
        mock_response = MagicMock()
        mock_response.text = '{"response": "Test AI response v2"}'
        requests_mock = MagicMock()
        requests_mock.request.return_value = mock_response

        with unittest.mock.patch('your_module.requests', requests_mock):
            result = get_ai_responsev2(api_key=self.api_key, question="What is the capital of India?")

        self.assertEqual(result, '{"response": "Test AI response v2"}')
        requests_mock.request.assert_called_once()

    def test_get_ai_responsev3(self):
        # Mock response
        mock_response = MagicMock()
        mock_response.text = '{"response": "Test AI response v3"}'
        requests_mock = MagicMock()
        requests_mock.request.return_value = mock_response

        with unittest.mock.patch('your_module.requests', requests_mock):
            result = get_ai_responsev3(api_key=self.api_key, question="What is the capital of India?")

        self.assertEqual(result, '{"response": "Test AI response v3"}')
        requests_mock.request.assert_called_once()

    def test_get_large_ai_response_v2(self):
        # Mock response
        mock_response = MagicMock()
        mock_response.text = '{"response": "Test Large AI response v2"}'
        requests_mock = MagicMock()
        requests_mock.request.return_value = mock_response

        with unittest.mock.patch('your_module.requests', requests_mock):
            result = get_large_ai_response_v2(api_key=self.api_key, question="What is the capital of Delhi?", dataset_id="123456789")

        self.assertEqual(result, '{"response": "Test Large AI response v2"}')
        requests_mock.request.assert_called_once()

    def test_get_alpha_ai_response(self):
        # Mock response
        mock_response = MagicMock()
        mock_response.text = '{"response": "Test Alpha AI response"}'
        requests_mock = MagicMock()
        requests_mock.request.return_value = mock_response

        with unittest.mock.patch('your_module.requests', requests_mock):
            result = get_alpha_ai_response(api_key=self.api_key, question="What is the capital of Delhi?")

        self.assertEqual(result, '{"response": "Test Alpha AI response"}')
        requests_mock.request.assert_called_once()

if __name__ == '__main__':
    unittest.main()



import requests
import os 

def fetch_all_collections(api_key=None):
    if not api_key:
        api_key = os.getenv("API_KEY")
    if not api_key:
        raise ValueError("API key is missing. Provide it as an argument or in the .env file.")
    url = "https://api.worqhat.com/api/collections/fetch-all"
    headers = {
        "Authorization": "Bearer " + api_key
    }

    response = requests.post("POST",url, headers=headers)

    return response.text

def fetch_all_docs_from_collection(collection='', output_type="json",api_key=None,):
    if collection=='':
        return ("Please enter a Collection name")
    if not api_key:
        api_key = os.getenv("API_KEY")
    if not api_key:
        raise ValueError("API key is missing. Provide it as an argument or in the .env file.")
    url = "https://api.worqhat.com/api/collections/data/fetch/all"
    payload = {
        "collection": collection,
        "outputType": output_type
    }
    headers = {
        "Authorization": "Bearer " + api_key,
        "Content-Type": "application/json"
    }

    response = requests.post("POST",url, json=payload, headers=headers)

    return response.text

def fetch_doc_from_collection( collection='', doc_id='',api_key=None):
    if collection=='':
        return ("Please enter a Collection name")
    if not api_key:
        api_key = os.getenv("API_KEY")
    if not api_key:
        raise ValueError("API key is missing. Provide it as an argument or in the .env file.")
    url = "https://api.worqhat.com/api/collections/data/fetch/document"
    payload = {
        "collection": collection,
        "documentId": doc_id
    }
    headers = {
        "Authorization": "Bearer " + api_key,
        "Content-Type": "application/json"
    }

    response = requests.post("POST",url, json=payload, headers=headers)

    return response.text

def fetch_doc_count_by_field(collection='', field='',api_key=None):
    if collection=='':
        return ("Please enter a Collection name")
    if not api_key:
        api_key = os.getenv("API_KEY")
    if not api_key:
        raise ValueError("API key is missing. Provide it as an argument or in the .env file.")
    url = "https://api.worqhat.com/api/collections/data/fetch/count"
    payload = {
        "collection": collection,
        "key": field
    }
    headers = {
        "Authorization": "Bearer " + api_key,
        "Content-Type": "application/json"
    }

    response = requests.post("POST",url, json=payload, headers=headers)

    return response.text

def fetch_unique_keys_ordered(collection='', field='', order_by='', order_type='',api_key=None):
    if collection=='':
        return ("Please enter a Collection name")
    if not api_key:
        api_key = os.getenv("API_KEY")
    if not api_key:
        raise ValueError("API key is missing. Provide it as an argument or in the .env file.")
    url = "https://api.worqhat.com/api/collections/data/fetch/unique"
    payload = {
        "collection": collection,
        "key": field,
        "orderBy": order_by,
        "orderType": order_type
    }
    headers = {
        "Authorization": "Bearer " + api_key,
        "Content-Type": "application/json"
    }

    response = requests.post("POST",url, json=payload, headers=headers)

    return response.text

def fetch_docs_by_query(collection='', queries='', compounding="and", order_by=None, order_type="asc", limit=None, start_after=None, output_type="json",api_key=None ):
    if collection=='':
        return ("Please enter a Collection name")
    if not api_key:
        api_key = os.getenv("API_KEY")
    if not api_key:
        raise ValueError("API key is missing. Provide it as an argument or in the .env file.")
    url = "https://api.worqhat.com/api/collections/data/fetch/query"
    payload = {
        "collection": collection,
        "queries": queries,
        "compounding": compounding,
        "orderBy": order_by,
        "orderType": order_type,
        "limit": limit,
        "startAfter": start_after,
        "outputType": output_type
    }
    headers = {
        "Authorization": "Bearer " + api_key,
        "Content-Type": "application/json"
    }

    response = requests.post("POST",url, json=payload, headers=headers)

    return response.text

def fetch_docs_by_natural_query(collection='', query='', output_type="json",api_key=None ):
    if collection=='':
        return ("Please enter a Collection name")
    if not api_key:
        api_key = os.getenv("API_KEY")
    if not api_key:
        raise ValueError("API key is missing. Provide it as an argument or in the .env file.")
    url = "https://api.worqhat.com/api/collections/data/fetch/natural-query"
    payload = {
        "collection": collection,
        "query": query,
        "outputType": output_type
    }
    headers = {
        "Authorization": "Bearer " + api_key,
        "Content-Type": "application/json"
    }

    response = requests.post("POST",url, json=payload, headers=headers)

    return response.text




import unittest
from unittest.mock import MagicMock
from ..src.ai_models.ai_search import search_ai_v2, search_ai_v3

class TestAISearch(unittest.TestCase):

    def setUp(self):
        # Mock API key for testing
        self.api_key = "mock_api_key"

    def test_search_ai_v2(self):
        # Mock response
        mock_response = MagicMock()
        mock_response.text = '{"result": "Test result for AI v2"}'
        requests_mock = MagicMock()
        requests_mock.request.return_value = mock_response

        with unittest.mock.patch('ai_search.requests', requests_mock):
            result = search_ai_v2(api_key=self.api_key, question="Test question")

        self.assertEqual(result, '{"result": "Test result for AI v2"}')
        requests_mock.request.assert_called_once()

    def test_search_ai_v3(self):
        # Mock response
        mock_response = MagicMock()
        mock_response.text = '{"result": "Test result for AI v3"}'
        requests_mock = MagicMock()
        requests_mock.request.return_value = mock_response

        with unittest.mock.patch('ai_search.requests', requests_mock):
            result = search_ai_v3(api_key=self.api_key, question="Test question")

        self.assertEqual(result, '{"result": "Test result for AI v3"}')
        requests_mock.request.assert_called_once()

if __name__ == '__main__':
    unittest.main()



import unittest
from unittest.mock import MagicMock
import requests
from ..src.ai_models.model_train import list_datasets, delete_dataset, train_dataset

class TestDatasetFunctions(unittest.TestCase):

    def setUp(self):
        # Mock API key for testing
        self.api_key = "mock_api_key"

    def test_list_datasets(self):
        # Mock response
        mock_response = MagicMock()
        mock_response.text = '{"datasets": ["Dataset1", "Dataset2"]}'
        requests_mock = MagicMock()
        requests_mock.request.return_value = mock_response

        with unittest.mock.patch('your_module.requests', requests_mock):
            result = list_datasets(api_key=self.api_key)

        self.assertEqual(result, '{"datasets": ["Dataset1", "Dataset2"]}')
        requests_mock.request.assert_called_once()

    def test_delete_dataset(self):
        # Mock response
        mock_response = MagicMock()
        mock_response.text = '{"message": "Dataset deleted successfully"}'
        requests_mock = MagicMock()
        requests_mock.request.return_value = mock_response

        with unittest.mock.patch('your_module.requests', requests_mock):
            result = delete_dataset(api_key=self.api_key, dataset_id="123456789")

        self.assertEqual(result, '{"message": "Dataset deleted successfully"}')
        requests_mock.request.assert_called_once()

    def test_train_dataset(self):
        # Mock response
        mock_response = MagicMock()
        mock_response.text = '{"message": "Dataset trained successfully"}'
        requests_mock = MagicMock()
        requests_mock.request.return_value = mock_response

        with unittest.mock.patch('your_module.requests', requests_mock):
            result = train_dataset(api_key=self.api_key, dataset_id="123456789", dataset_name="Sample Dataset", dataset_type="self", json_data="{'data':'This is sample Data'}", training_file="sample_training_data.txt")

        self.assertEqual(result, '{"message": "Dataset trained successfully"}')
        requests_mock.request.assert_called_once()

if __name__ == '__main__':
    unittest.main()



import requests
import os 

def create_collection(collection='', collection_schema='', collection_sort_by='',api_key=None ):
    if collection=='':
        return ("Please enter a Collection name")
    if not api_key:
        api_key = os.getenv("API_KEY")
    if not api_key:
        raise ValueError("API key is missing. Provide it as an argument or in the .env file.")
    url = "https://api.worqhat.com/api/collections/create"
    headers = {
        "Authorization": "Bearer " + api_key,
        "Content-Type": "application/json"
    }

    payload = {
        "collection": collection,
        "collectionSchema": collection_schema,
        "collectionSortBy": collection_sort_by
    }

    response = requests.post("POST",url, json=payload, headers=headers)

    return response.text


import unittest
from unittest.mock import MagicMock
import requests
from ..src.ai_models.content_mod import content_moderation,image_moderation

class TestModeration(unittest.TestCase):

    def setUp(self):
        # Mock API key for testing
        self.api_key = "mock_api_key"

    def test_content_moderation(self):
        # Mock response
        mock_response = MagicMock()
        mock_response.text = '{"result": "Test content moderation result"}'
        requests_mock = MagicMock()
        requests_mock.request.return_value = mock_response

        with unittest.mock.patch('moderation.requests', requests_mock):
            result = content_moderation(api_key=self.api_key, text_content="Test text content")

        self.assertEqual(result, '{"result": "Test content moderation result"}')
        requests_mock.request.assert_called_once()

    def test_image_moderation(self):
        # Mock response
        mock_response = MagicMock()
        mock_response.text = '{"result": "Test image moderation result"}'
        requests_mock = MagicMock()
        requests_mock.request.return_value = mock_response

        with unittest.mock.patch('moderation.requests', requests_mock):
            result = image_moderation(api_key=self.api_key, image_file=MagicMock(name="mock_image_file"))

        self.assertEqual(result, '{"result": "Test image moderation result"}')
        requests_mock.request.assert_called_once()

if __name__ == '__main__':
    unittest.main()



import unittest
from unittest.mock import MagicMock
import requests
from ..src.ai_models.image_analysis import image_analysis, face_detection, facial_comparison

class TestImageFunctions(unittest.TestCase):

    def setUp(self):
        # Mock API key for testing
        self.api_key = "mock_api_key"

    def test_image_analysis(self):
        # Mock response
        mock_response = MagicMock()
        mock_response.text = '{"result": "Test image analysis result"}'
        requests_mock = MagicMock()
        requests_mock.request.return_value = mock_response

        with unittest.mock.patch('your_module.requests', requests_mock):
            result = image_analysis(api_key=self.api_key, images=[MagicMock(name="mock_image")], question="Test question")

        self.assertEqual(result, '{"result": "Test image analysis result"}')
        requests_mock.request.assert_called_once()

    def test_face_detection(self):
        # Mock response
        mock_response = MagicMock()
        mock_response.text = '{"result": "Test face detection result"}'
        requests_mock = MagicMock()
        requests_mock.request.return_value = mock_response

        with unittest.mock.patch('your_module.requests', requests_mock):
            result = face_detection(api_key=self.api_key, image_file=MagicMock(name="mock_image_file"))

        self.assertEqual(result, '{"result": "Test face detection result"}')
        requests_mock.request.assert_called_once()

    def test_facial_comparison(self):
        # Mock response
        mock_response = MagicMock()
        mock_response.text = '{"result": "Test facial comparison result"}'
        requests_mock = MagicMock()
        requests_mock.request.return_value = mock_response

        with unittest.mock.patch('your_module.requests', requests_mock):
            result = facial_comparison(api_key=self.api_key, source_image_file=MagicMock(name="mock_source_image_file"), target_image_file=MagicMock(name="mock_target_image_file"))

        self.assertEqual(result, '{"result": "Test facial comparison result"}')
        requests_mock.request.assert_called_once()

if __name__ == '__main__':
    unittest.main()



import requests 
import json
import os
def get_ai_response_v2(question="", 
                       preserve_history=False, 
                       randomness=0.5, 
                       stream_data=False, 
                       conversation_history=[], 
                       training_data="", 
                       response_type="text",
                       api_key=None):
    url = "https://api.worqhat.com/api/ai/content/v2"

    payload = {
        "question": question,
        "preserve_history": preserve_history,
        "randomness": randomness,
        "stream_data": stream_data,
        "conversation_history": conversation_history,
        "training_data": training_data,
        "response_type": response_type
    }

    headers = {"Content-Type": "application/json"}

    if not api_key:
        api_key = os.getenv("API_KEY")

    if api_key:
        headers["Authorization"] = "Bearer " + api_key
    else:
        raise ValueError("API key is missing. Provide it as an argument or in the .env file.")

    response = requests.post(url, json=payload, headers=headers, stream=stream_data)

    if stream_data:
        for line in response.iter_lines():
            if line:
                if line.startswith(b'data:'):
                    json_content = line[len(b'data:'):].decode('utf-8').strip()
                    print(json_content)
    else:
        json_response = response.text
        try:
            json_data = json.loads(json_response)
            return(json.dumps(json_data, indent=4))
        except json.JSONDecodeError:
            print(json_response)


def get_ai_response_v3(question="", 
                       preserve_history=False, 
                       randomness=0.5, 
                       stream_data=False, 
                       conversation_history=[], 
                       training_data="", 
                       response_type="text",
                       api_key=None):
    url = "https://api.worqhat.com/api/ai/content/v3"

    payload = {
        "question": question,
        "preserve_history": preserve_history,
        "randomness": randomness,
        "stream_data": stream_data,
        "conversation_history": conversation_history,
        "training_data": training_data,
        "response_type": response_type
    }

    headers = {"Content-Type": "application/json"}

    if not api_key:
        api_key = os.getenv("API_KEY")

    if api_key:
        headers["Authorization"] = "Bearer " + api_key
    else:
        raise ValueError("API key is missing. Provide it as an argument or in the .env file.")

    response = requests.post(url, json=payload, headers=headers, stream=stream_data)

    if stream_data:
        for line in response.iter_lines():
            if line:
                if line.startswith(b'data:'):
                    json_content = line[len(b'data:'):].decode('utf-8').strip()
                    print(json_content)
    else:
        json_response = response.text
        try:
            json_data = json.loads(json_response)
            print(json.dumps(json_data, indent=4))
        except json.JSONDecodeError:
            print(json_response)


def get_alpha_ai_response(question="", 
                          preserve_history=False, 
                          randomness=0.5, 
                          stream_data=False, 
                          conversation_history=[], 
                          training_data="", 
                          response_type="text",
                          api_key=None):
    url = "https://api.worqhat.com/api/ai/content/v3/alpha"
    payload = {
        "question": question,
        "preserve_history": preserve_history,
        "randomness": randomness,
        "stream_data": stream_data,
        "conversation_history": conversation_history,
        "training_data": training_data,
        "response_type": response_type
    }
    headers = {"Content-Type": "application/json"}
    if not api_key:
        api_key = os.getenv("API_KEY")
    if api_key:
        headers["Authorization"] = "Bearer " + api_key
    else:
        raise ValueError("API key is missing. Provide it as an argument or in the .env file.")
    response = requests.request("POST",url, json=payload, headers=headers)
    if stream_data:
        for line in response.iter_lines():
            if line:
                if line.startswith(b'data:'):
                    json_content = line[len(b'data:'):].decode('utf-8').strip()
                    print(json_content)
    else:
        json_response = response.text
        try:
            json_data = json.loads(json_response)
            print(json.dumps(json_data, indent=4))
        except json.JSONDecodeError:
            print(json_response)


def get_large_ai_response_v2(question="", 
                             dataset_id="", 
                             preserve_history=True, 
                             randomness=0.5, 
                             stream_data=False, 
                             conversation_history=[], 
                             instructions=None,
                             api_key=None):
    url = "https://api.worqhat.com/api/ai/content/v2-large/answering"
    payload = {
        "question": question,
        "datasetId": dataset_id,
        "preserve_history": preserve_history,
        "randomness": randomness,
        "stream_data": stream_data,
        "conversation_history": conversation_history,
        "instructions": instructions
    }
    headers = {"Content-Type": "application/json"}
    if not api_key:
        api_key = os.getenv("API_KEY")
    if api_key:
        headers["Authorization"] = "Bearer " + api_key
    else:
        raise ValueError("API key is missing. Provide it as an argument or in the .env file.")
    response = requests.request("POST",url, json=payload, headers=headers)
    if stream_data:
        for line in response.iter_lines():
            if line:
                if line.startswith(b'data:'):
                    json_content = line[len(b'data:'):].decode('utf-8').strip()
                    print(json_content)
    else:
        json_response = response.text
        try:
            json_data = json.loads(json_response)
            print(json.dumps(json_data, indent=4))
        except json.JSONDecodeError:
            print(json_response)



import requests
import os
import json

def analyze_images(images, question="", training_data="", output_type="text", stream_data=False, api_key=None):
    if not images or len(images) == 0:
        return "No images found. Please try again "

    api_key = api_key or os.getenv("API_KEY")
    if not api_key:
        raise ValueError("API key is missing. Provide it as an argument or in the .env file.")
    url = "https://api.worqhat.com/api/ai/images/v2/image-analysis"
    headers = {
        'Accept': 'application/json',
        'Authorization': f'Bearer {api_key}'
    }
    payload = {
        'output_type': output_type,
        'stream_data': str(stream_data).lower(),
        'question': question,
        'training' : training_data
    }
    files = []
    for image in images:
        if image.startswith('http://') or image.startswith('https://'):
            response = requests.get(image)
            files.append(('images', (os.path.basename(image), response.content, 'image/jpeg')))
        else:
            with open(image, 'rb') as f:
                file_content = f.read()
                files.append(('images', (os.path.basename(image), file_content, 'image/jpeg')))
    response = requests.post(url, headers=headers, data=payload, files=files)
    if stream_data:
        for line in response.iter_lines():
            if line:
                if line.startswith(b'data:'):
                    json_content = line[len(b'data:'):].decode('utf-8').strip()
                    print(json_content)
    else:
        json_response = response.text
        try:
            json_data = json.loads(json_response)
            print(json.dumps(json_data, indent=4))
        except json.JSONDecodeError:
            print(json_response)

def detect_faces(image, api_key=None):
    if not image or len(image) == 0:
        return "No images found. Please try again "
    api_key = api_key or os.getenv("API_KEY")
    if not api_key:
        raise ValueError("API key is missing. Provide it as an argument or in the .env file.")
    url = "https://api.worqhat.com/api/ai/images/v2/face-detection"
    headers = {
        'Accept': 'application/json',
        'Authorization': f'Bearer {api_key}'
    }

    if image.startswith('http://') or image.startswith('https://'):
        response = requests.get(image)
        file=[('image', (os.path.basename(image), response.content, 'image/jpeg'))]
    else:
        with open(image, 'rb') as f:
            file=[('image', (os.path.basename(image), f, 'image/jpeg'))]
    response = requests.post(url, headers=headers, files=file)
    return response.text

def compare_faces(source_image, target_image, api_key=None):
    if not source_image or not target_image:
        return "No images found. Please try again "
    api_key = api_key or os.getenv("API_KEY")
    if not api_key:
        raise ValueError("API key is missing. Provide it as an argument or in the .env file.")
    url = "https://api.worqhat.com/api/ai/images/v2/facial-comparison"
    headers = {
        'Accept': 'application/json',
        'Authorization': f'Bearer {api_key}'
    }
   
    if source_image.startswith('http://') or source_image.startswith('https://'):
        response = requests.get(source_image)
        source_file=[('source_image', (os.path.basename(source_image), response.content, 'image/jpeg'))]
    else:
        with open(source_image, 'rb') as f:
           source_file=[('source_image', (os.path.basename(source_image), f, 'image/jpeg'))]
    if target_image.startswith('http://') or target_image.startswith('https://'):
        response = requests.get(target_image)
        target_file=[('target_image', (os.path.basename(target_image), response.content, 'image/jpeg'))]
    else:
        with open(target_image, 'rb') as f:
            target_file=[('target_image', (os.path.basename(target_image), f, 'image/jpeg'))]
    files = source_file + target_file
    response = requests.post(url, headers=headers, files=files)
    return response.text



import unittest
from unittest.mock import MagicMock
import requests
from ..src.ai_models.text_extract import pdf_extract, web_extract, image_text_detection, speech_to_text

class TestFunctions(unittest.TestCase):

    def setUp(self):
        # Mock API key for testing
        self.api_key = "mock_api_key"

    def test_pdf_extract(self):
        # Mock response
        mock_response = MagicMock()
        mock_response.text = '{"result": "Test pdf extraction result"}'
        requests_mock = MagicMock()
        requests_mock.request.return_value = mock_response

        with unittest.mock.patch('your_module.requests', requests_mock):
            result = pdf_extract(api_key=self.api_key, pdf_file=MagicMock(name="mock_pdf_file"))

        self.assertEqual(result, '{"result": "Test pdf extraction result"}')
        requests_mock.request.assert_called_once()

    def test_web_extract(self):
        # Mock response
        mock_response = MagicMock()
        mock_response.text = '{"result": "Test web extraction result"}'
        requests_mock = MagicMock()
        requests_mock.request.return_value = mock_response

        with unittest.mock.patch('your_module.requests', requests_mock):
            result = web_extract(api_key=self.api_key, url_search="www.example.com")

        self.assertEqual(result, '{"result": "Test web extraction result"}')
        requests_mock.request.assert_called_once()

    def test_image_text_detection(self):
        # Mock response
        mock_response = MagicMock()
        mock_response.text = '{"result": "Test image text detection result"}'
        requests_mock = MagicMock()
        requests_mock.request.return_value = mock_response

        with unittest.mock.patch('your_module.requests', requests_mock):
            result = image_text_detection(api_key=self.api_key, image_file=MagicMock(name="mock_image_file"))

        self.assertEqual(result, '{"result": "Test image text detection result"}')
        requests_mock.request.assert_called_once()

    def test_speech_to_text(self):
        # Mock response
        mock_response = MagicMock()
        mock_response.text = '{"result": "Test speech to text result"}'
        requests_mock = MagicMock()
        requests_mock.request.return_value = mock_response

        with unittest.mock.patch('your_module.requests', requests_mock):
            result = speech_to_text(api_key=self.api_key, audio_file=MagicMock(name="mock_audio_file"))

        self.assertEqual(result, '{"result": "Test speech to text result"}')
        requests_mock.request.assert_called_once()

if __name__ == '__main__':
    unittest.main()



from setuptools import find_packages, setup

with open("app/README.md", "r") as f:
    long_description = f.read()

setup(
    name="worqhat",
    version="1.0",
    description="A package with all the APIs available from worqHat",
    package_dir={"": "app"},
    packages=find_packages(where="app"),
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/Ayush-Kul/worqhat-python",
    author="WorqHat",
    author_email="support@worqhat.com",
    license="MIT",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3.10",
        "Operating System :: OS Independent",
    ],
    install_requires=[],
    extras_require={
        "dev": ["pytest>=7.0", "twine>=4.0.2"],
    },
    python_requires=">=3.10",
)


import requests 
import os


def list_datasets(api_key=None):
    if not api_key:
        api_key = os.getenv("API_KEY")
    if not api_key:
        raise ValueError("API key is missing. Provide it as an argument or in the .env file.")
    url = "https://api.worqhat.com/api/list-datasets"
    headers = {"Authorization": "Bearer " + api_key}
    response = requests.post(url, headers=headers)
    return response.text
    
def delete_dataset(dataset_id="", api_key=None):
    if dataset_id=="":
        raise ValueError("No Dataset Id provided")
    if not api_key:
        api_key = os.getenv("API_KEY")
    if not api_key:
        raise ValueError("API key is missing. Provide it as an argument or in the .env file.")
    url = f"https://api.worqhat.com/api/delete-datasets/{dataset_id}"
    headers = {"Authorization": "Bearer " + api_key}
    response = requests.post(url, headers=headers)
    return response.text

    
def train_dataset(dataset_id="", dataset_name="", dataset_type="", json_data="", training_file=None, api_key=None):
    if dataset_id=="":
        raise ValueError("No Dataset Id provided")
    if not api_key:
        api_key = os.getenv("API_KEY")
    if not api_key:
        raise ValueError("API key is missing. Provide it as an argument or in the .env file.")
    url = "https://api.worqhat.com/api/ai/datasets/train-datasets"
    headers = {"Authorization": "Bearer " + api_key}
    payload = {
            "datasetId": dataset_id,
            "dataset_name": dataset_name,
            "dataset_type": dataset_type,
            "json_data": (None, json_data),
            "training_file": (training_file, open(training_file, 'rb'))
    }
    response = requests.post(url, files=payload, headers=headers)
    return response.text



import requests
import os


def generate_image_v2(prompt=[""], image_style="realistic", output_type="url", orientation="square", api_key=None):
    if not api_key:
        api_key = os.getenv("API_KEY")
    if not api_key:
         raise ValueError("API key is missing. Provide it as an argument or in the .env file.")
    url = "https://api.worqhat.com/api/ai/images/generate/v2"
    headers = {
        "Authorization": "Bearer " + api_key,
        "Content-Type": "application/json"
    }
    payload = {
        "prompt": prompt,
        "image_style": image_style,
        "output_type": output_type,
        "orientation": orientation
    }
    response = requests.post(url, json=payload, headers=headers)
    return response.text

def generate_image_v3(prompt=[], image_style="realistic", output_type="url", orientation="square", api_key=None):
    if not api_key:
        api_key = os.getenv("API_KEY")

    if not api_key:
         raise ValueError("API key is missing. Provide it as an argument or in the .env file.")
    url = "https://api.worqhat.com/api/ai/images/generate/v3"
    headers = {
        "Authorization": "Bearer " + api_key,
        "Content-Type": "application/json"
    }
    payload = {
        "prompt": prompt,
        "image_style": image_style,
        "output_type": output_type,
        "orientation": orientation
    }
    response = requests.post(url, json=payload, headers=headers)
    return response.text

def modify_image_v2(image=None,modification=None, output_type="URL", similarity="30",  api_key=None):
    if not modification:
        return "Modification description is missing"
    if not image or len(image) == 0:
        return "Image is missing"
    if not api_key:
        api_key = os.getenv("API_KEY")
    if not api_key:
         raise ValueError("API key is missing. Provide it as an argument or in the .env file.")
    url = "https://api.worqhat.com/api/ai/images/modify/v2"
    headers = {
        "Authorization": f"Bearer {api_key}"
    }
    payload = {
            "modification": modification,
            "output_type": output_type,
            "similarity": similarity
        }
    if image.startswith('http://') or image.startswith('https://'):
        response = requests.get(image)
        files = [('existing_image', ('file', response.content, 'application/octet-stream'))]
    else:
        with open(image, 'rb') as f:
            files = [('existing_image', ('file', f, 'application/octet-stream'))]
    response = requests.post(url, headers=headers, data=payload, files=files)
    return response.text


def modify_image_v3(image=None,modification=None, output_type="URL", similarity="30",  api_key=None):
    if not modification:
        return "Modification description is missing"
    if not image or len(image) == 0:
        return "Existing images are missing"
    if not api_key:
        api_key = os.getenv("API_KEY")

    # If api_key is still not available, return an error message
    if not api_key:
        raise ValueError("API key is missing. Provide it as an argument or in the .env file.")

    url = "https://api.worqhat.com/api/ai/images/modify/v3"
    headers = {
        "Authorization": f"Bearer {api_key}"
    }



        # Prepare payload
    payload = {
            "modification": modification,
            "output_type": output_type,
            "similarity": similarity
        }

        # Prepare files data in the required format
    if image.startswith('http://') or image.startswith('https://'):
            # If image is a URL, download the image content
        response = requests.get(image)
        files = [('existing_image', ('file', response.content, 'application/octet-stream'))]
    else:
        # If image is a local file path, read the file content
        with open(image, 'rb') as f:
            files = [('existing_image', ('file', f, 'application/octet-stream'))]

        # Make the API call
    response = requests.post(url, headers=headers, data=payload, files=files)
    return response.text

def remove_text_from_image(image=None,output_type="URL",  api_key=None):

    if not image:
        return "Existing image is missing"
    if not api_key:
        api_key = os.getenv("API_KEY")
    if not api_key:
        raise ValueError("API key is missing. Provide it as an argument or in the .env file.")
    url = "https://api.worqhat.com/api/ai/images/modify/v3/remove-text"
    headers = {
        "Authorization": f"Bearer {api_key}"
    }

    payload = {'output_type': output_type}

    if image.startswith('http://') or image.startswith('https://'):
        response = requests.get(image)
        files = [('existing_image', ('file', response.content, 'image/png'))]
    else:
        with open(image, 'rb') as f:
            files = [('existing_image', ('file', f, 'image/png'))]

    response = requests.post(url, headers=headers, data=payload, files=files)
    return response.text

def remove_background_from_image(existing_image=None,output_type="URL",  api_key=None):
    if not existing_image:
        return "Existing image is missing"
    if not api_key:
        api_key = os.getenv("API_KEY")
    if not api_key:
       raise ValueError("API key is missing. Provide it as an argument or in the .env file.")

    url = "https://api.worqhat.com/api/ai/images/modify/v3/remove-background"
    headers = {
        "Authorization": f"Bearer {api_key}"
    }
    payload = {'output_type': output_type}
    if existing_image.startswith('http://') or existing_image.startswith('https://'):
        response = requests.get(existing_image)
        files = [('existing_image', ('file', response.content, 'image/png'))]
    else:
        with open(existing_image, 'rb') as f:
            files = [('existing_image', ('file', f, 'image/png'))]
    response = requests.post(url, headers=headers, data=payload, files=files)
    return response.text

def replace_background(image=None,modification=None, output_type="URL",  api_key=None):
    if not modification:
        return "Modification description is missing"
    if not image:
        return "Existing image is missing"
    if not api_key:
        api_key = os.getenv("API_KEY")
    if not api_key:
        raise ValueError("API key is missing. Provide it as an argument or in the .env file.")

    url = "https://api.worqhat.com/api/ai/images/modify/v3/replace-background"
    headers = {
        "Authorization": f"Bearer {api_key}"
    }

    payload = {
        "modification": modification,
        "output_type": output_type
    }

    if image.startswith('http://') or image.startswith('https://'):
        response = requests.get(image)
        files = [('existing_image', ('file', response.content, 'image/png'))]
    else:
        with open(image, 'rb') as f:
            files = [('existing_image', ('file', f, 'image/png'))]
    response = requests.post(url, headers=headers, data=payload, files=files)
    return response.text

def search_replace_image(image=None,modification=None, output_type="URL", search_object=None,  api_key=None):
    if not modification:
        return "Modification description is missing"
    if not search_object:
        return "Search object description is missing"
    if not image:
        return "Existing image is missing"
    if not api_key:
        api_key = os.getenv("API_KEY")
    if not api_key:
        raise ValueError("API key is missing. Provide it as an argument or in the .env file.")
    url = "https://api.worqhat.com/api/ai/images/modify/v3/search-replace-image"
    headers = {
        "Authorization": f"Bearer {api_key}"
    }
    payload = {
        "modification": modification,
        "output_type": output_type,
        "search_object": search_object
    }

    if image.startswith('http://') or image.startswith('https://'):

        response = requests.get(image)
        files = [('existing_image', ('file', response.content, 'image/png'))]
    else:
  
        with open(image, 'rb') as f:
            files = [('existing_image', ('file', f, 'image/png'))]
    response = requests.post(url, headers=headers, data=payload, files=files)
    return response.text


def extend_image(image=None,output_type="URL", left_extend="100", right_extend="100", top_extend="50", bottom_extend="50", description="",  api_key=None):
    if not image:
        return "image is missing"
    if not api_key:
        api_key = os.getenv("API_KEY")
    if not api_key:
        raise ValueError("API key is missing. Provide it as an argument or in the .env file.")

    url = "https://api.worqhat.com/api/ai/images/modify/v3/extend-image"
    headers = {
        "Authorization": f"Bearer {api_key}"
    }

    payload = {
        "output_type": output_type,
        "leftExtend": left_extend,
        "rightExtend": right_extend,
        "topExtend": top_extend,
        "bottomExtend": bottom_extend,
        "description": description
    }

    if image.startswith('http://') or image.startswith('https://'):

        response = requests.get(image)
        files = [('existing_image', ('file', response.content, 'image/png'))]
    else:
        with open(image, 'rb') as f:
            files = [('existing_image', ('file', f, 'image/png'))]

    response = requests.post(url, headers=headers, data=payload, files=files)
    return response.text

def upscale_image(existing_image=None,scale="4", output_type="URL",api_key=None):
    if not existing_image:
        return "Existing image is missing"
    if not api_key:
        api_key = os.getenv("API_KEY")
    if not api_key:
        raise ValueError("API key is missing. Provide it as an argument or in the .env file.")

    url = "https://api.worqhat.com/api/ai/images/upscale/v3"
    headers = {
        "Authorization": f"Bearer {api_key}"
    }
    payload = {
        "scale": scale,
        "output_type": output_type
    }

    if existing_image.startswith('http://') or existing_image.startswith('https://'):

        response = requests.get(existing_image)
        files = [('existing_image', ('file', response.content, 'image/png'))]
    else:
        with open(existing_image, 'rb') as f:
            files = [('existing_image', ('file', f, 'image/png'))]

    response = requests.post(url, headers=headers, data=payload, files=files)

    return response.text


import os
import requests

def search_ai_v2(question="", training_data="", api_key=None):
    if question == "":
        return "Question is incomplete. Please give a question and try again."
    if not api_key:
        api_key = os.getenv("API_KEY")
    if not api_key:
        raise ValueError("API key is missing. Provide it as an argument or in the .env file.")
    url = "https://api.worqhat.com/api/ai/search/v2"
    headers = {
        "Authorization": "Bearer " + api_key,
        "Content-Type": "application/json"
    }
    payload = {
        "question": question,
        "training_data": training_data
    }
    response = requests.request("POST", url, json=payload, headers=headers)
    return response.text

def search_ai_v3(question="", training_data="", search_count=10, api_key=None):
    if question == "":
        return "Question is incomplete. Please give a question and try again"
    if not api_key:
        api_key = os.getenv("API_KEY")
    if not api_key:
        raise ValueError("API key is missing. Provide it as an argument or in the .env file.")
    url = "https://api.worqhat.com/api/ai/search/v3"
    headers = {
        "Authorization": "Bearer " + api_key,
        "Content-Type": "application/json"
    }
    payload = {
        "question": question,
        "training_data": training_data,
        "search_count": search_count
    }
    response = requests.request("POST", url, json=payload, headers=headers)
    return response.text



__all__ = ['ai_search', 'content_mod', 'image_analysis', 'image_gen', 'model_train', 'text_extract', 'text_gen']

from .ai_search import *
from .content_mod import *
from .image_analysis import *
from .image_gen import *
from .model_train import *
from .text_extract import *
from .text_gen import *


import requests
import os 


def add_data_to_collection(collection='', doc_id='', data='',api_key=None ):
    if collection=='':
        return ("Please enter a Collection name")
    if not api_key:
        api_key = os.getenv("API_KEY")
    if not api_key:
        raise ValueError("API key is missing. Provide it as an argument or in the .env file.")
    url = "https://api.worqhat.com/api/collections/data/add"
    headers = {
        "Authorization": "Bearer " + api_key,
        "Content-Type": "application/json"
    }

    payload = {
        "collection": collection,
        "docId": doc_id,
        "data": data
    }

    response = requests.post("POST",url, json=payload, headers=headers)

    return response.text

def update_data_in_collection( collection='', doc_id='', data='',api_key=None):
    if collection=='':
        return ("Please enter a Collection name")
    if not api_key:
        api_key = os.getenv("API_KEY")
    if not api_key:
        raise ValueError("API key is missing. Provide it as an argument or in the .env file.")
    url = "https://api.worqhat.com/api/collections/data/update"
    headers = {
        "Authorization": "Bearer " + api_key,
        "Content-Type": "application/json"
    }

    payload = {
        "collection": collection,
        "docId": doc_id,
        "data": data
    }

    response = requests.post(url, json=payload, headers=headers)

    return response.text

def increment_field_in_collection(collection='', doc_id='', field='', increment_value='',api_key=None):
    if collection=='':
        return ("Please enter a Collection name")
    if not api_key:
        api_key = os.getenv("API_KEY")
    if not api_key:
        raise ValueError("API key is missing. Provide it as an argument or in the .env file.")
    url = "https://api.worqhat.com/api/collections/data/increment"
    headers = {
        "Authorization": "Bearer " + api_key,
        "Content-Type": "application/json"
    }

    payload = {
        "collection": collection,
        "docId": doc_id,
        "field": field,
        "increment": increment_value
    }

    response = requests.post(url, json=payload, headers=headers)

    return response.text

def update_array_in_collection(collection='', doc_id='', field='', value='',api_key=None ):
    if collection=='':
        return ("Please enter a Collection name")
    if not api_key:
        api_key = os.getenv("API_KEY")
    if not api_key:
        raise ValueError("API key is missing. Provide it as an argument or in the .env file.")
    url = "https://api.worqhat.com/api/collections/data/array/update/add"
    payload = {
        "collection": collection,
        "docId": doc_id,
        "field": field,
        "arrayUnion": value
    }
    headers = {
        "Authorization": "Bearer " + api_key,
        "Content-Type": "application/json"
    }

    response = requests.post(url, json=payload, headers=headers)

    return response.text

def remove_array_element_from_collection(collection='', doc_id='', field='', value='',api_key=None):
    if collection=='':
        return ("Please enter a Collection name")
    if not api_key:
        api_key = os.getenv("API_KEY")
    if not api_key:
        raise ValueError("API key is missing. Provide it as an argument or in the .env file.")
    url = "https://api.worqhat.com/api/collections/data/array/update/remove"
    payload = {
        "collection": collection,
        "docId": doc_id,
        "field": field,
        "arrayRemove": value
    }
    headers = {
        "Authorization": "Bearer " + api_key,
        "Content-Type": "application/json"
    }

    response = requests.post(url, json=payload, headers=headers)

    return response.text

def delete_doc_from_collection(collection='', doc_id='',api_key=None):
    if collection=='':
        return ("Please enter a Collection name")
    if not api_key:
        api_key = os.getenv("API_KEY")
    if not api_key:
        raise ValueError("API key is missing. Provide it as an argument or in the .env file.")
    url = "https://api.worqhat.com/api/collections/data/delete"
    payload = {
        "collection": collection,
        "docId": doc_id
    }
    headers = {
        "Authorization": "Bearer " + api_key,
        "Content-Type": "application/json"
    }

    response = requests.post(url, json=payload, headers=headers)

    return response.text
